@@ -1,7 +1,5 @@
 #' Suggest datasets in GBIF.
 #'
-#' Search that returns up to 20 matching datasets. Results are ordered by relevance.
-#'
 #' @export
 #' @template otherlimstart
 #' @template occ
@@ -24,32 +22,32 @@
 #'
 #' # Suggest datasets owned by the organization with key
 #' # "07f617d0-c688-11d8-bf62-b8a03c50a862" (UK NBN).
-#' head(dataset_suggest(owningOrg="07f617d0-c688-11d8-bf62-b8a03c50a862"))
+#' dataset_suggest(owningOrg="07f617d0-c688-11d8-bf62-b8a03c50a862")
 #'
 #' # Fulltext search for all datasets having the word "amsterdam" somewhere in
 #' # its metadata (title, description, etc).
-#' head(dataset_suggest(query="amsterdam"))
+#' dataset_suggest(query="amsterdam")
 #'
 #' # Limited search
 #' dataset_suggest(type="OCCURRENCE", limit=2)
 #' dataset_suggest(type="OCCURRENCE", limit=2, start=10)
 #'
 #' # Return just descriptions
-#' dataset_suggest(type="OCCURRENCE", description=TRUE)
+#' dataset_suggest(type="OCCURRENCE", limit = 5, description=TRUE)
 #'
 #' # Return metadata in a more human readable way (hard to manipulate though)
-#' dataset_suggest(type="OCCURRENCE", pretty=TRUE)
+#' dataset_suggest(type="OCCURRENCE", limit = 5, pretty=TRUE)
 #'
 #' # Search by country code. Lookup isocodes first, and use US for United States
 #' isocodes[agrep("UNITED", isocodes$gbif_name),]
-#' head(dataset_suggest(country="US"))
+#' dataset_suggest(country="US", limit = 25)
 #'
 #' # Search by decade
-#' head(dataset_suggest(decade=1980))
+#' dataset_suggest(decade=1980, limit = 30)
 #'
 #' # httr options
 #' library('httr')
-#' dataset_suggest(type="OCCURRENCE", limit=2, config=verbose())
+#' dataset_suggest(type="OCCURRENCE", limit = 2, config=verbose())
 #' }
 
 dataset_suggest <- function(query = NULL, country = NULL, type = NULL, subtype = NULL,
@@ -64,40 +62,36 @@ dataset_suggest <- function(query = NULL, country = NULL, type = NULL, subtype =
                        decade=decade,limit=limit,offset=start))
   tt <- gbif_GET(url, args, FALSE, ...)
 
-  if(description){
+  if (description) {
     out <- sapply(tt, "[[", "description")
     names(out) <- sapply(tt, "[[", "title")
     out <- rgbif_compact(out)
-  } else
-  {
-    if(length(tt)==1){
-      out <- parse_suggest(x=tt$results)
-    } else
-    {
-      out <- do.call(rbind_fill, lapply(tt, parse_suggest))
+  } else {
+    if (length(tt) == 1) {
+      out <- parse_suggest(x = tt$results)
+    } else {
+      out <- tibble::as_data_frame(do.call(rbind_fill, lapply(tt, parse_suggest)))
     }
   }
 
-  if(pretty){
-    if(length(tt)==1){
+  if (pretty) {
+    if (length(tt) == 1) {
       invisible(print_suggest(tt))
-    } else
-    {
+    } else {
       invisible(lapply(tt, print_suggest)[[1]])
     }
-  } else
-  {
+  } else {
     return( out )
   }
 }
 
 parse_suggest <- function(x){
   tmp <- rgbif_compact(list(
-    key=x$key,
-    type=x$type,
-    title=x$title
+    key = x$key,
+    type = x$type,
+    title = x$title
   ))
-  data.frame(tmp, stringsAsFactors=FALSE)
+  tibble::as_data_frame(tmp)
 }
 
 print_suggest <- function(x){
@@ -106,5 +100,5 @@ print_suggest <- function(x){
     paste("type:", x$type),
     paste("datasetTitle:", x$title),
     paste("description:", x$description),
-    "\n", sep="\n")
+    "\n", sep = "\n")
 }
