@@ -11,7 +11,7 @@ test_that("query all datasets returns the correct class", {
 test_that("single dataset query returns the correct", {
   skip_on_cran()
   tt <- datasets(uuid="a6998220-7e3a-485d-9cd6-73076bd85657")
-  
+
   # class
   expect_is(tt, "list")
   expect_null(tt$meta)
@@ -25,9 +25,9 @@ test_that("single dataset query returns the correct", {
 
 test_that("contact returns the correct class", {
   skip_on_cran()
-  
+
   tt <- datasets(data='contact', uuid="a6998220-7e3a-485d-9cd6-73076bd85657")
-  
+
   # class
   expect_is(tt, "list")
   expect_null(tt$meta)
@@ -37,24 +37,28 @@ test_that("contact returns the correct class", {
   expect_equal(tt$data$lastName[1], "Fisher")
 })
 
-tt <- datasets(data='metadata', uuid="a6998220-7e3a-485d-9cd6-73076bd85657")
 test_that("metadata returns the correct class", {
+  skip_on_cran()
+
+  tt <- datasets(data='metadata', uuid="a6998220-7e3a-485d-9cd6-73076bd85657")
+
+  # correct classes
   expect_is(tt, "list")
   expect_null(tt$meta)
   expect_is(tt$data$key, "integer")
-})
-test_that("metadata returns the correct value", {
+
+  # correct values
   expect_equal(tt$data$type, "EML")
 })
 
 test_that("search for deleted and duplicate datasets returns the correct", {
   skip_on_cran()
-  
+
   tt <- datasets(data=c('deleted','duplicate'))
-  
+
   # class
   expect_is(tt, "list")
-  
+
   # dimensions
   expect_equal(length(tt), 2)
   expect_equal(length(tt[[1]]), 2)
