@@ -10,14 +10,14 @@ test_that("returns the correct class", {
 
   expect_is(tt, "data.frame")
   expect_is(uu, "data.frame")
-  expect_is(uu$scientificName, "character")
-  expect_is(uu$bracketYear, "character")
+  expect_is(uu$scientificname, "character")
+  expect_is(uu$bracketyear, "character")
 
   # returns the correct value
-  expect_equal(as.character(tt$scientificName[[1]]), "x Agropogon littoralis")
-  expect_equal(as.character(uu$specificEpithet[[1]]), "elatius")
+  expect_equal(as.character(tt$scientificname[[1]]), "x Agropogon littoralis")
+  expect_equal(as.character(uu$specificepithet[[1]]), "elatius")
 
   # returns the correct dimensions
-  expect_equal(dim(tt), c(1,9))
-  expect_equal(dim(uu), c(4,12))
+  expect_equal(dim(tt), c(1,11))
+  expect_equal(dim(uu), c(4,13))
 })
